package internal
import "github.com/googleapis/gax-go/v2/internallog/internal"
Package internal provides some common logic and types to other logging sub-packages.
Index ¶
Constants ¶
const ( // LoggingLevelEnvVar is the environment variable used to enable logging // at a particular level. LoggingLevelEnvVar = "GOOGLE_SDK_GO_LOGGING_LEVEL" )
Functions ¶
func NewLoggerWithWriter ¶
NewLoggerWithWriter is exposed for testing.
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| internallog/internal/bookpb | |
| internallog/internal/logtest | Package logtest is a helper for validating logging tests. |
- Version
- v2.14.2 (latest)
- Published
- May 13, 2025
- Platform
- linux/amd64
- Imports
- 6 packages
- Last checked
- 4 months ago –
Tools for package owners.